@@ -85,6 +85,7 @@ DDropdownMenu::DDropdownMenu(QWidget *parent)
 #else
     m_pToolButton->setFixedHeight(s_DDropdownMenuHeight);
 #endif
+    qDebug() << "DDropdownMenu constructor end";
 }
 
 DDropdownMenu::~DDropdownMenu()
@@ -92,17 +93,22 @@ DDropdownMenu::~DDropdownMenu()
     qDebug() << "DDropdownMenu destructor";
     deleteMenuActionGroup();
     deleteMenu();
+    qDebug() << "DDropdownMenu destructor end";
 }
 
 void DDropdownMenu::setFontEx(const QFont& font)
 {
+    qDebug() << "DDropdownMenu setFontEx";
     m_pToolButton->setFont(font);
     m_font = font;
+    qDebug() << "DDropdownMenu setFontEx end";
 }
 
 void DDropdownMenu::setCurrentAction(QAction *pAct)
 {
+    qDebug() << "DDropdownMenu setCurrentAction";
     if(pAct){
+        qDebug() << "pAct is not null";
         QList<QAction*> menuList = m_menu->actions();
         pAct->setChecked(true);
         for (int i = 0; i < menuList.size(); i++) {
@@ -113,11 +119,13 @@ void DDropdownMenu::setCurrentAction(QAction *pAct)
         }
         setText(pAct->text());
     }
+    qDebug() << "DDropdownMenu setCurrentAction end";
 }
 
 void DDropdownMenu::setCurrentTextOnly(const QString &name)
 {
-  // QList<QAction*> menuList = m_menu->actions();
+    qDebug() << "DDropdownMenu setCurrentTextOnly";
+    // QList<QAction*> menuList = m_menu->actions();
 
 //   for (int i = 0; i < menuList.size(); i++) {
 //       if(menuList[i]->menu()){
@@ -140,35 +148,43 @@ void DDropdownMenu::setCurrentTextOnly(const QString &name)
    }
 
    setText(name);
+   qDebug() << "DDropdownMenu setCurrentTextOnly end";
 }
 
 
 void DDropdownMenu::setCheckedExclusive(QAction* action,const QString& name)
 {
-    if(nullptr == action){
+    qDebug() << "DDropdownMenu setCheckedExclusive";
+    if (nullptr == action) {
+        qDebug() << "action is null, return";
         return;
     }
 
-    if(action->menu()){
+    if (action->menu()) {
+        qDebug() << "action has menu";
         for(auto ac:action->menu()->actions()){
             setCheckedExclusive(ac,name);
         }
-    }
-    else {
-        if(action->text() != name){
+    } else {
+        qDebug() << "action has no menu";
+        if (action->text() != name) {
+            qDebug() << "action text is not equal to name";
             action->setCheckable(false);
             action->setChecked(false);
-        }
-        else{
+        } else {
+            qDebug() << "action text is equal to name";
             action->setCheckable(true);
             action->setChecked(true);
         }
     }
+    qDebug() << "DDropdownMenu setCheckedExclusive end";
 }
 
 void DDropdownMenu::slotRequestMenu(bool request)
 {
+    qDebug() << "DDropdownMenu slotRequestMenu";
     if (request) {
+        qDebug() << "request is true";
         //如果鼠标点击清除ｆｏｃｕｓ
         m_pToolButton->clearFocus();
     }
@@ -190,45 +206,58 @@ void DDropdownMenu::slotRequestMenu(bool request)
     QApplication::sendEvent(m_pToolButton, &event);
 #endif
     emit sigSetTextEditFocus();
+    qDebug() << "DDropdownMenu slotRequestMenu end";
 }
 
 void DDropdownMenu::setText(const QString &text)
 {
+    qDebug() << "DDropdownMenu setText:" << text;
     m_text = text;
     //重新绘制icon　设置宽度
     m_pToolButton->setIcon(createIcon());
+    qDebug() << "DDropdownMenu setText end";
 }
 
 void DDropdownMenu::setMenu(DMenu *menu)
 {
+    qDebug() << "DDropdownMenu setMenu";
     deleteMenu();
     m_menu = menu;
 }
 
 void DDropdownMenu::deleteMenu()
 {
+    qDebug() << "DDropdownMenu deleteMenu";
     if (m_menu != nullptr) {
+        qDebug() << "m_menu is not null, deleting";
         delete m_menu;
         m_menu = nullptr;
     }
+    qDebug() << "DDropdownMenu deleteMenu end";
 }
 
 void DDropdownMenu::setMenuActionGroup(QActionGroup *actionGroup)
 {
+    qDebug() << "DDropdownMenu setMenuActionGroup";
     deleteMenuActionGroup();
     m_actionGroup = actionGroup;
+    qDebug() << "DDropdownMenu setMenuActionGroup end";
 }
 
 void DDropdownMenu::deleteMenuActionGroup()
 {
+    qDebug() << "DDropdownMenu deleteMenuActionGroup";
     if (m_actionGroup != nullptr) {
+        qDebug() << "m_actionGroup is not null, deleting";
         delete m_actionGroup;
         m_actionGroup = nullptr;
     }
+    qDebug() << "DDropdownMenu deleteMenuActionGroup end";
 }
 
 void DDropdownMenu::setTheme(const QString &theme)
 {
+    qDebug() << "DDropdownMenu setTheme:" << theme;
     QString arrowSvgPath = QString(":/images/dropdown_arrow_%1.svg").arg(theme);
     // 根据当前显示缩放转换图片
     qreal scaled = this->devicePixelRatioF();
@@ -243,53 +272,67 @@ void DDropdownMenu::setTheme(const QString &theme)
 
     m_arrowPixmap = pixmap;
     m_pToolButton->setIcon(createIcon());
+    qDebug() << "DDropdownMenu setTheme end";
 }
 
 void DDropdownMenu::setChildrenFocus(bool ok)
 {
-    if(ok)  m_pToolButton->setFocusPolicy(Qt::StrongFocus);
-    else  {
+    qDebug() << "DDropdownMenu setChildrenFocus:" << ok;
+    if (ok) {
+        qDebug() << "setChildrenFocus is true";
+        m_pToolButton->setFocusPolicy(Qt::StrongFocus);
+    } else  {
+        qDebug() << "setChildrenFocus is false";
         m_pToolButton->clearFocus();
         m_pToolButton->setFocusPolicy(Qt::NoFocus);
     }
+    qDebug() << "DDropdownMenu setChildrenFocus end";
 }
 
 void DDropdownMenu::setRequestMenu(bool request)
 {
+    qDebug() << "DDropdownMenu setRequestMenu:" << request;
     isRequest = request;
+    qDebug() << "DDropdownMenu setRequestMenu end";
 }
 
 DToolButton *DDropdownMenu::getButton()
 {
+    qDebug() << "DDropdownMenu getButton";
     return m_pToolButton;
 }
 
 QString DDropdownMenu::getCurrentText() const
 {
+    qDebug() << "DDropdownMenu getCurrentText";
     return m_text;
 }
 
 DDropdownMenu *DDropdownMenu::createEncodeMenu()
 {
+    qDebug() << "DDropdownMenu createEncodeMenu";
     DDropdownMenu *m_pEncodeMenu = new DDropdownMenu();
     DMenu* m_pMenu = new DMenu();
 
     auto groupEncodeVec = Utils::getSupportEncoding();
     if (!groupEncodeVec.isEmpty()) {
+        qDebug() << "groupEncodeVec is not empty, creating menu";
         int cnt = groupEncodeVec.size();
         for (int i = 0; i < cnt;i++) {
             QMenu* groupMenu = new QMenu(QObject::tr(groupEncodeVec[i].first.toLocal8Bit().data()));
              foreach(QString var, groupEncodeVec[i].second)
              {
                QAction *act= groupMenu->addAction(QObject::tr(var.toLocal8Bit().data()));
-               if(act->text() == "UTF-8") {
-                   m_pEncodeMenu->m_pActUtf8 = act;
-                   act->setCheckable(true);
-                   act->setChecked(true);
-               }else {
-                   act->setCheckable(false);
+               if (act->text() == "UTF-8") {
+                    qDebug() << "Adding UTF-8 action";
+                    m_pEncodeMenu->m_pActUtf8 = act;
+                    act->setCheckable(true);
+                    act->setChecked(true);
+               } else {
+                    qDebug() << "Adding other action";
+                    act->setCheckable(false);
                }
-             }
+            }
 
             m_pMenu->addMenu(groupMenu);
         }
@@ -299,6 +342,7 @@ DDropdownMenu *DDropdownMenu::createEncodeMenu()
         qInfo() << "Encoding changed to:" << action->text();
         //编码内容改变触发内容改变和信号发射 梁卫东 2020.7.7
         if (m_pEncodeMenu->m_text != action->text()) {
+            qDebug() << "Encoding changed to:" << action->text();
             emit m_pEncodeMenu->currentActionChanged(action);
         }
     });
@@ -306,11 +350,13 @@ DDropdownMenu *DDropdownMenu::createEncodeMenu()
     m_pEncodeMenu->setText("UTF-8");
     m_pEncodeMenu->setMenu(m_pMenu);
 
+    qDebug() << "DDropdownMenu createEncodeMenu end";
     return  m_pEncodeMenu;
 }
 
 DDropdownMenu *DDropdownMenu::createHighLightMenu()
 {
+    qDebug() << "DDropdownMenu createHighLightMenu";
     DDropdownMenu *m_pHighLightMenu = new DDropdownMenu();
     DMenu *m_pMenu = new DMenu;
     QAction *noHlAction = m_pMenu->addAction(tr("None"));
@@ -329,18 +375,22 @@ DDropdownMenu *DDropdownMenu::createHighLightMenu()
         if(def.translatedName()=="Intel x86 (NASM)"&&intel)
         {
             intel = false;
+            qDebug() << "Intel x86 (NASM) is hidden, continue";
             continue;
         }
         if (def.isHidden()) {
+            qDebug() << "def is hidden, continue";
             continue;
         }
 
         if (currentGroup != def.section()) {
+            qDebug() << "currentGroup is not equal to def.section(), creating new submenu";
             currentGroup = def.section();
             pSubMenu = m_pMenu->addMenu(def.translatedSection());
         }
 
         if (!pSubMenu) {
+            qDebug() << "pSubMenu is null, continue";
             continue;
         }
 
@@ -376,21 +426,25 @@ DDropdownMenu *DDropdownMenu::createHighLightMenu()
     m_pHighLightMenu->setMenu(m_pMenu);
     m_pHighLightMenu->setMenuActionGroup(m_pActionGroup);
 
+    qDebug() << "DDropdownMenu createHighLightMenu end";
     return m_pHighLightMenu;
 }
 
 QIcon DDropdownMenu::createIcon()
 {
+    qDebug() << "DDropdownMenu createIcon";
     DPalette dpalette  = DPaletteHelper::instance()->palette(m_pToolButton);
     QColor textColor;
 
     QPixmap arrowPixmap;
 
     if(m_bPressed){
+        qDebug() << "Button is pressed, changing icon color";
         textColor = dpalette.color(DPalette::Highlight);
         QString color = textColor.name(QColor::HexRgb);
         arrowPixmap = setSvgColor(color);
     }else {
+        qDebug() << "Button is not pressed, using default icon color";
         textColor = dpalette.color(DPalette::WindowText);
         arrowPixmap = m_arrowPixmap;
     }
@@ -432,15 +486,18 @@ QIcon DDropdownMenu::createIcon()
     painter.drawPixmap(QRectF(fontWidth,(totalHeigth-iconH)/2,iconW,iconH),arrowPixmap,arrowPixmap.rect());
 
     painter.end();
+    qDebug() << "DDropdownMenu createIcon end";
     return icon;
 }
 
 void DDropdownMenu::OnFontChangedSlot(const QFont &font)
 {
+    qDebug() << "DDropdownMenu OnFontChangedSlot";
     m_font = font;
     int fontsize =DFontSizeManager::instance()->fontPixelSize(DFontSizeManager::T8);
     m_font.setPixelSize(fontsize);
     m_pToolButton->setIcon(createIcon());
+    qDebug() << "DDropdownMenu OnFontChangedSlot end";
 }
 
 
@@ -451,6 +508,7 @@ bool DDropdownMenu::eventFilter(QObject *object, QEvent *event)
         // 处理字体变化
         QFont font = qApp->font(); // 获取当前应用程序字体
         OnFontChangedSlot(font);   // 调用槽函数更新字体
+        qDebug() << "DDropdownMenu eventFilter ApplicationFontChange, return true";
         return true;
     }
 #endif
@@ -465,6 +523,7 @@ bool DDropdownMenu::eventFilter(QObject *object, QEvent *event)
                 Q_EMIT requestContextMenu(false);
                 return true;
             }
+            qDebug() << "Key event not handled, return false";
             return false;
         }
 
@@ -479,11 +538,13 @@ bool DDropdownMenu::eventFilter(QObject *object, QEvent *event)
             }
 
             if(mouseEvent->button() == Qt::RightButton){
+                qDebug() << "Right mouse button pressed on dropdown menu, return true";
                 return true;
             }
         }
 
         if(event->type() == QEvent::MouseButtonRelease){
+            qDebug() << "Left mouse button released on dropdown menu";
             QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
             if(mouseEvent->button() == Qt::LeftButton){
                 m_bPressed = false;
@@ -494,14 +555,17 @@ bool DDropdownMenu::eventFilter(QObject *object, QEvent *event)
                 }
                 m_pToolButton->clearFocus();
             }
+            qDebug() << "Left mouse button released, return true";
             return true;
         }
     }
+
     return QFrame::eventFilter(object,event);
 }
 
 QPixmap DDropdownMenu::setSvgColor(QString color)
 {
+    qDebug() << "DDropdownMenu setSvgColor";
     //设置图标颜色
     QString path = QString(":/images/arrow_dark.svg");
     QFile file(path);
@@ -525,14 +589,16 @@ QPixmap DDropdownMenu::setSvgColor(QString color)
     QPainter painter(&pixmap);
     svg_render.render(&painter,QRect(0,0,8,5));
 
+    qDebug() << "DDropdownMenu setSvgColor end";
     return pixmap;
 }
 
 void DDropdownMenu::SetSVGBackColor(QDomElement &elem, QString strattr, QString strattrval)
 {
-
+    qDebug() << "DDropdownMenu SetSVGBackColor";
     if (elem.tagName().compare("g") == 0 && elem.attribute("id").compare("color") == 0)
     {
+        qDebug() << "DDropdownMenu SetSVGBackColor, found color group";
         QString before_color = elem.attribute(strattr);
         elem.setAttribute(strattr, strattrval);
     }
@@ -542,4 +608,5 @@ void DDropdownMenu::SetSVGBackColor(QDomElement &elem, QString strattr, QString
         QDomElement element = elem.childNodes().at(i).toElement();
         SetSVGBackColor(element, strattr, strattrval);
     }
+    qDebug() << "DDropdownMenu SetSVGBackColor end";
 }
